{                            LLPARSE.PAS                                    }

Function llparse:boolean;
{       ************************************************************
        *                                                          *
        *                         llparse                          *
        *                                                          *
        ************************************************************

    Este procedimiento es disenado para analizar programas GAUSS de acuerdo al
    metodo de PARSE LL(1). El algoritmo para este procedimiento ha sido tomado
    del libro " The Theory and Practice of Compiler Writing " de Tremblay and
    Sorenson's de la seccion 6-2.5 . Las tablas necesarias son descritas abajo
    La correspondencia entre las variables del aquel algoritmo y este programa
    son las siguientes:

           Nombre del Algoritmo               Nombre del Programa
                  PARSE                          parse
                  PARSE_TOP                      parse_top
                  CURRENT_INPUT                  next_token
                  LL1_PARSETAB                   ll1_parsetab
                  TRUE_TOP                       true_top

    La siguiente tabla abarca la tabla parse LL(1) tal como se genero del la
    gramatica para gauss. Cada grupo de lineas separadas por dos espacios re-
    presenta un renglon de la tabla. Las entidades marcadas por 'Apop' indican
    que al stack debe hacerse un pop. 'Aerror' indica un error en una entidad,
    y un 'Aaccept' indica una entidad aceptada. Entidades con valores enteros
    entre 1 y 136 representa una expancion de la gramatica que debe ser ejecu-
    tada con el simbolo dado sobre el tope del stack y el simbolo actual de en-
    trada. Por ejemplo, la entrada 3 significa que la tercera produccion de la
    gramatica debe ser aplicada. Las expanciones son obtenidas desde las tablas
    'prod_index' y 'rhs_prod' tables.

                       Apop = 159 ;
                       Aaccept = 160 ;
                       Aerror  = 161 ;
                                                                              }
 Type
{     parse_table = array[1..N_of_symbols,1..N_of_terminals] of byte;         }
     parse_stack = array[1..parse_limit] of token;

 const
        {  Nota : La constante "ll1_parsetab" se declarara ahora como una
                  variable global, por limitaciones del segmento de codigo con
                  que cuenta el compilador de Turbo Pascal.                   }

                                                                              {
     La siguiente tabla es utilizada para obtener las partes derechas de las --
     producciones de la gramatica. Por ejemplo, si queremos el lado derecho de
     la produccion 43, entonces "prod_index[43]" dara un indice a la tabla  --
     "rhs_prod" donde esta informacion puede ser encontrada. Esto permite el --
     utilizar el numero de la produccion de la gramatica para referenciar su --
     lado derecho, tal como un offset a la tabla "rsh_table".
                                                                              }
    prod_index : array[1..139] of integer =
            ( 1,3,7,10,14,18,21,21,25,31,
            31,35,41,44,50,50,52,53,54,55,
            56,64,67,67,71,74,75,77,79,82,
            84,86,88,90,95,99,99,103,103,109,
            111,112,120,124,124,128,128,131,131,134,
            136,144,147,147,148,149,150,151,152,153,
            154,155,160,164,164,167,167,169,171,178,
            179,182,182,184,186,187,194,199,205,205,
            215,217,225,237,242,243,244,246,247,249,
            251,254,254,256,264,270,272,272,274,277,
            280,283,286,289,292,292,294,298,302,307,
            307,309,313,317,321,326,326,329,332,333,
            336,338,341,341,343,347,347,350,354,358,
            362,372,382,384,386,388,390,391,392 );
                                                                              {
     La siguiente tabla contiene las partes derechas de cada produccion de la -
     gramatica LL(1) para GAUSS. La tabla toma la forma de un vector. Para en -
     contrar los tokens de una produccion en particular, digamos la 26, es ne -
     cesario utilizar la tabla "pro_index[26]" la cual nos dara el indice a es-
     ta tabla, donde comenzara la definicion para esta produccion.
                                                                              }

    rhs_prod : array[1..391] of token =
         { 1 - <program> ::=  }
              ( Sglobal,Neof,
         { 2 - <global> :: =  }
               NN221,Sprocedure,Nsemi,Sprocedure_list,
         { 3 - <global> :: = }
               NN204,Stype_specifier,Score,
         { 4 - <core>  ::=  }
               NN222,Sprocedure,Nsemi,Sprocedure_list,
         { 5 - <core>  ::=  }
               Sentity_list,NN203,Nsemi,Sglobal,
         { 6 - <declaration list> ::= }
               Sdeclaration,Nsemi,Sdeclaration_list,
         { 7 - <declaration list> ::= null }
         { 8.- <procedure_list>::=  }
               NN221,Sprocedure,Nsemi,Sprocedure_list,
         { 9 - <procedure list> ::= }
               Ssimple_type,NN221,NN205,Sprocedure,Nsemi,Sprocedure_list,
         { 10 - <procedure list> ::= null }
         { 11 - <declaration> ::= }
                NN204,Stype_specifier,Sentity_list,NN203,
         { 12 - <entity list> ::= }
                Nconst,Nnewident,NN201,Neq,Sconstant,Sconstant_list,
         { 13 - <entity list > ::= }
                Nnewident,NN202,Sident_list,
         { 14 - <const list> ::= }
                Ncomma,Nnewident,NN201,Neq,Sconstant,Sconstant_list,
         { 15 - <const list> ::=null }
         { 16 - <type specifier> ::= }
                Ssimple_type,NN205,
         { 17 - <type specifier> ::= }
                Sarray,
         { 18 - <simple type> ::= }
                Ninteger,
         { 19 - <simple type> ::= }
                Nstring,
         { 20 - <simple type> ::= }
                Nlogical,
         { 21 - <array> ::= }
                Narray,Nlparen,Sbound_pair,Sbound_pair_list,Nrparen,Nof,
                Ssimple_type,NN216,
         { 22 - <bound_pair_list>::= }
                Ncomma,Sbound_pair,Sbound_pair_list,
         { 23 - <bound_pair_list> ::= null   }
         { 24 - <bound_pair> ::=  }
                NN206,Sexpression,NN207,Ssecond_bound,
         { 25 - <second bound> }
                Ncolon,Sexpression,NN207,
         { 26 - <secon bound> ::= null }
                NN208,
         { 27 - <constant> ::= }
                Ssimple_constant, NN209,
         { 28 - <constant> ::= }
                Sarray_constant,NN210,
         { 29 - <simple constant> ::= }
                Numinus,Nnumber,NN211,
         { 30 - <simple constant> ::= }
                Nnumber,NN212,
         { 31 - <simple constant> ::= }
                Nliteral,NN213,
         { 32 - <simple constant> ::= }
                Ntrue,NN214,
         { 33 - <simple constant> ::= }
                Nfalse,NN215,
         { 34 - <array constant> ::= }
                Nlparen,Ssimple_constant,NN217,Ssimple_constant_list,Nrparen,
         { 35 - <simple constant list> ::= }
                Ncomma,Ssimple_constant,NN217,Ssimple_constant_list,
         { 36 - <simple constant list> := null }
         { 37 - <ident_list> ::= }
                Ncomma,Nnewident,NN202,Sident_list,
         { 38 - <ident list> ::= null }
         { 39 - <procedure> := }
                Nproc,Sproc_name,NN219,Sparameter_list,NN220,Sprocedure_tail,
         { 40 - <procedure tail> ::= }
                Nforward,NN226,
         { 41 - <procedure tail> ::= }
                Sprocedure_body,
         { 42 - <procedure body> ::= }
                Sdeclaration_list,NN228,NN289,Sstatement,Nsemi,Sstatement_list,
                Nendproc,NN229,
         { 43 - <statment list> ::= }
                NN289,Sstatement,Nsemi,Sstatement_list,
         { 44 - <statement list> ::= null }
         { 45 - <parameter list> ::= }
                Nlparen,Sparameter,Sparameters,Nrparen,
         { 46 - <parameter list> ::= null }
         { 47 - <parameters> ::= }
                Ncomma,Sparameter,Sparameters,
         { 48 - <parameters> ::= null }
         { 49 - <parameter> ::= }
                Sparameter_type,Nnewident,NN224,
         { 50 - <parameter type> ::= }
                Ssimple_type,NN205,
         { 51 - <parameter type> ::= }
                Narray,Nlparen,NN225,Scomma_list,Nrparen,Nof,Ssimple_type,
                NN205,
         { 52 - <comma list> ::= }
                Ncomma,NN225,Scomma_list,
         { 53 - <comma list> ::= null }
         { 54 - <statement> ::= }
                Sprocedure_call,
         { 55 - <statement> ::= }
                Sreturn_stmt,
         { 56 - <statement> ::= }
                Sif_stmt,
         { 57 - <statement> ::= }
                Swhile_stmt,
         { 58 - <statement> ::= }
                Sstop_stmt,
         { 59 - <statment> ::= }
                Sassignment_stmt,
         { 60 - <statement> ::= }
                Sread_stmt,
         { 61 - <statment> ::= }
                Swrite_stmt,
         { 62 - <procedure_call> ::= }
                Nprocident,NN248,Sargument_list,NN249,NN270,
         { 63 - <argument list> ::= }
                Nlparen,Sargument,Sarguments,Nrparen,
         { 64 - <argument list> ::= null }
         { 65 - <arguments> ::= }
                Ncomma,Sargument,Sarguments,
         { 66 - <arguments> ::= null }
         { 67 - <argument> ::= }
                Nsimpident,NN260,
         { 68 - <argument> ::= }
                Narrayident,Ssublist,
         { 69 - <sublist> ::= }
                NN253,Nlparen,Sexpression,Sexpressions,Nrparen,NN254,NN261,
         { 70 - <sublist> ::= null }
                NN260,
         { 71 - <expressions> ::= }
                Ncomma,Sexpression,Sexpressions,
         { 72 - <expressions> ::=  null }
         { 73 - <return stmt> ::= }
                Nreturn,Sret_expression,
         { 74 - <ret expression ::= }
                Sexpression,NN271,
         { 75 - <ret expression> ::= null }
                NN272,
         { 76 - <if stmt> ::= }
                Nif,Sexpression,NN273,Sthen_clause,Selse_clause,NN275,Nendif,
         { 77 - <then clause> ::= }
                Nthen,NN289,Sstatement,Nsemi,Sstatement_list,
         { 78 - <else clause> ::= }
                NN274,Nelse,NN289,Sstatement,Nsemi,Sstatement_list,
         { 79 - <else clause> ::= null }
         { 80 - <while stmt> ::= }
                NN276,Nloop,Sstatement_list,Nwhile,Sexpression,NN273,Nsemi,
                Sstatement_list,NN277,Nendloop,
         { 81 - <stop stmt> ::= }
                Nstop,NN280,
         { 82 - <assigment stmt> ::= }
                Nsimpident,NN284,Ssubstring,NN279,NN281,Nassign,Sexpression,
                NN282,
         { 83 - <assigment stmt> ::= }
                Narrayident,NN253,Nlparen,Sexpression,Sexpressions,Nrparen,
                NN254,Ssubstring,NN279,Nassign,Sexpression,NN283,
         { 84 - <substring> ::= }
                Nlparen,Sstart,Nsubstr,Slength,Nrparen,
         { 85 - <substring> ::= null }
                NN265,
         { 86 - <start> ::= }
                Sexpression,
         { 87 - <length> ::= }
                Sexpression,NN266,
         { 88 - <length> ::= null }
                NN267,
         { 89 - <read stmt> ::= }
                Nread,Sinput_goal_list,
         { 90 - <input goal list> ::= }
                Sinput_goal,Sinput_goals,
         { 91 - <input goals> ::= }
                Ncomma,Sinput_goal,Sinput_goals,
         { 92 - <input goals> ::= null }
         { 93 - <input goal> ::= }
                Nsimpident,NN285,
         { 94 - <input goal> ::= }
                Narrayident,NN253,Nlparen,Sexpression,Sexpressions,Nrparen,
                NN254,NN286,
         { 95 - <write stmt> ::= }
                Nwrite,NN287,Sexpression_list,Nusing,Nliteral,NN288,
         { 96 - <expression list> ::= }
                Sexpression,Sexpressions,
         { 97 - <expression list> ::= null }
         { 98 - <expression> ::= }
                Spart,Setail,
         { 99 - <etail> ::= }
                Ngt,Spart,NN230,
         { 100 - <etail> ::= }
                 Nlt,Spart,NN231,
         { 101 - <etail> ::= }
                 Neq,Spart,NN232,
         { 102 - <etail> ::= }
                 Nge,Spart,NN233,
         { 103 - <etail> ::= }
                 Nle,Spart,NN234,
         { 104 - <etail> ::= }
                 Nne,Spart,NN235,
         { 105 - <etail> ::= null }
         { 106 - <part> ::= }
                 Sterm,Sptail,
         { 107 - <ptail> ::= }
                 Nplus,Sterm,NN236,Sptail,
         { 108 - <ptail> ::= }
                 Nminus,Sterm,NN237,Sptail,
         { 109 - <ptail. ::= }
                 Nor,NN238,Sterm,NN262,sptail,
         { 110 - <ptail> ::= null }
         { 111 - <term> ::= }
                 Sfactor,Sttail,
         { 112 - <ttail> ::= }
                 Nmult,Sfactor,NN239,Sttail,
         { 113 - <ttail> ::= }
                 Ndiv,Sfactor,NN240,Sttail,
         { 114 - <ttail> ::= }
                 Nmod,Sfactor,NN241,Sttail,
         { 115 - <ttail> ::= }
                 Nand,NN242,Sfactor,NN262,Sttail,
         { 116 - <ttail> ::= null }
         { 117 - <factor> ::= }
                 Nnot,Sindex,NN243,
         { 118 - <factor> ::= }
                 Numinus,Sindex,NN244,
         { 119 - <factor> ::= }
                 Sindex,
         { 120 - <index> ::= }
                 Nlength,Scatena,NN254,
         { 121 - <index> ::= }
                 Scatena,Sitail,
         { 122 - <itail> ::= }
                 Nindex,Scatena,NN246,
         { 123 - <itail> ::null }
         { 124 - <catena> ::= }
                 Sprimary,Sctail,
         { 125 - <ctail> ::= }
                 Nconcat,Sprimary,NN247,Sctail,
         { 126 - <ctail> ::= null }
         { 127 - <primary> ::= }
                 Nlparen,Sexpression,Nrparen,
         { 128 - <primary> ::= }
                 Nprocident,NN248,Sargument_list,NN249,
         { 129 - <primary> ::= }
                 Nsimpident,NN250,Ssubstring,NN251,
         { 130 - <primary> ::= }
                 Nsimpconident,NN252,Ssubstring,NN251,
         { 131 - <primary> ::= }
                 Narrayident,NN253,Nlparen,Sexpression,Sexpressions,Nrparen,
                 NN254,NN259,Ssubstring,NN251,
         { 132 - <primary> ::= }
                 Narrayconident,NN253,Nlparen,Sexpression,Sexpressions,Nrparen,
                 NN254,NN259,Ssubstring,NN251,
         { 133 - <primary> ::= }
                 Nnumber,NN255,
         { 134 - <primary> ::= }
                 Nliteral,NN256,
         { 135 - <primary> ::= }
                 Ntrue,NN257,
         { 136 - <primary> ::= }
                 Nfalse,NN258,
         { 137 - <proc_name> ::= }
                 Nnewident,
         { 138 - <proc_name> ::= }
                 Nprocident);
                                                                              {
        La tabla "prefix" es utilizada para determinar si el simbolo en el
        stack puede producir el simbolo de la entrada. La entidad 0 indica que
        esto no es posible. Todas las otras entidades xxxyy, donde "xxx" indica
        la produccion a la que debe ser expandida el simbolo del stack, y "yy"
        indica cual elemento de la expansion produce el simbolo de la entrada
        dado
                                                                              }

         prefix : array[58..N_of_symbols,1..N_of_terminals] of integer= (
{ program }
        (0,101,101,0,0,0,0,0,0,0,101,101,0,0,0,0,101,0,0,101,0,0,0,0,0,0,0,0,0,
         0,0,0,0,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0),
{ global }
         (0,301,201,0,0,0,0,0,0,0,301,301,0,0,0,0,201,0,0,301,0,0,0,0,0,0,0,0,
         0,0,0,0,0,201,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0),
{ core }
         (0,503,501,0,0,0,0,0,0,0,503,503,0,0,0,0,401,0,0,503,0,0,0,0,0,0,0,0,
         0,0,0,0,0,401,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0),
{ declaration list }
         (0,601,601,0,0,0,0,0,0,0,601,601,0,0,0,0,0,0,0,601,0,0,0,0,0,0,0,0,0,
         0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0),
{ procedure list }
         (0,801,801,0,0,0,0,0,0,0,901,901,0,0,0,0,801,0,0,901,0,0,0,0,0,0,0,0,
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0),
{ declaration }
         (0,1101,1102,0,0,0,0,0,0,0,1101,1101,0,0,0,0,0,0,0,1101,0,0,0,0,0,0,
          1101,1101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1102,0,0,1102,0,0,
          1102,1102,0,0),
{ entity list }
         (0,0,1201,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
         0,1203,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0),
{ constant list }
         (0,0,0,0,0,0,0,1404,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1404,0,0,0,0,0,0,0,
         1401,0,0,0,1403,0,0,0,0,0,0,1404,0,0,0,0,0,1402,0,0,0,1404,0,0,0,0,0),
{ type specifier }
         (0,1701,0,0,0,0,0,0,0,0,1601,1601,0,0,0,0,0,0,0,1601,0,0,0,0,0,0,0,0,
          0,1701,1701,0,0,0,0,0,0,0,0,0,0,1701,0,0,0,0,0,0,0,0,0,1701,0,0,0,0,
          0),
{ simple type }
         (0,0,0,0,0,0,0,0,0,0,1801,2001,0,0,0,0,0,0,0,1901,0,0,0,0,0,0,0,0,0,0,
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0),
{ array }
         (0,2101,0,0,0,0,0,0,0,0,2107,2107,0,0,2106,0,0,0,0,2107,0,0,0,0,0,0,0,
         0,0,2103,2104,0,0,0,0,0,0,0,0,0,0,2102,0,0,0,0,0,0,0,0,0,2105,0,0,0,0,
         0),
{ bound pair list }
         (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2202,2201,
          0,0,0,0,0,0,0,0,0,0,2202,0,2202,2202,0,0,0,2202,2202,0,2202,0,2202,
          2202,0,2202),
{ bound pair }
         (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2402,2401,
          0,0,0,0,0,0,0,0,0,0,2401,0,2401,2401,0,0,0,2401,2401,0,2401,0,2401,
          2401,0,2401),
{ second bound }
         (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2501,2502,
          0,0,0,0,0,0,0,0,0,0,2502,0,2502,2502,0,0,0,2502,2502,0,2502,0,2502,
          2502,0,2502),
{ constant }
         (0,0,0,0,0,0,0,2701,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2701,0,0,0,0,0,0,0,0,
          0,0,0,0,0,0,0,0,0,2701,2801,0,0,0,0,0,0,2701,0,0,2801,0,0,0,0,2701),
{ simple constant }
         (0,0,0,0,0,0,0,3301,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3201,0,0,0,0,0,0,0,0,
          0,0,0,0,0,0,0,0,0,3101,0,0,0,0,0,0,0,3001,0,0,0,0,0,0,0,2901),
{ array constant }
         (0,0,0,0,0,0,0,3402,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3402,0,0,0,0,0,0,0,
          3403,0,0,0,0,0,0,0,0,0,3402,3401,0,0,0,0,0,0,3402,0,0,3404,0,0,0,0,
          3402),
{ simple constant list }
         (0,0,0,0,0,0,0,3502,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3502,0,0,0,0,0,0,0,
          3501,0,0,0,0,0,0,0,0,0,3502,0,0,0,0,0,0,0,3502,0,0,0,0,0,0,0,3502),
{ ident list }
         (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3701,0,0,
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,3702,0,0,0,0,0,0,0,0,0),
{ procedure }
         (0,3903,3904,0,0,0,0,0,0,0,3903,3903,0,0,0,0,0,0,0,3903,0,0,0,0,0,0,0,
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3902,0,0,3902,0,0,0,0,0,0),
{ procedure tail }
         (4101,4101,4101,4101,4101,4101,4101,4101,4001,4101,4101,4101,4101,
          4101,4101,4101,0,4101,4101,4101,4101,4101,4101,4101,4101,4101,4101,
          4101,4101,4101,4101,4101,4101,0,4101,4101,4101,4101,4101,4101,4101,
          4101,4101,4101,4101,4101,4101,4101,4101,4101,4101,4101,4101,4101,4101,
          4101,4101),
{ procedure body }
         (4202,4201,4201,4202,4202,4202,4205,4202,0,4202,4201,4201,4202,4202,
          4201,4202,0,4202,4202,4201,4202,4202,4202,4202,4202,4202,4202,4202,
          4202,4201,4201,4202,4202,0,4202,4202,4202,4202,4202,4202,4202,4202,
          4202,4202,4202,4202,4202,4201,4202,4202,4202,4202,4203,4202,4202,
          4202,4202),
{ statement list }
         (0,0,0,0,0,0,0,0,0,4301,0,0,4301,0,0,0,0,4301,4301,0,4301,0,0,0,4301,
          4301,0,0,4301,0,0,4301,4301,0,4301,4301,4301,4301,4301,4301,4301,
          4301,4301,4301,4301,4301,4301,0,4301,4301,4301,4301,4302,4301,4301,
          4301,4301),
{ parameter list }
         (0,4502,0,0,0,0,0,0,0,0,4502,4502,0,0,4502,0,0,0,0,4502,0,0,0,0,0,0,0,
          0,0,0,4503,0,0,0,0,0,0,0,0,0,0,4501,0,0,0,0,0,4502,0,0,0,4504,0,0,0,
          0,0),
{ parameters }
         (0,4702,0,0,0,0,0,0,0,0,4702,4702,0,0,4702,0,0,0,0,4702,0,0,0,0,0,0,0,
          0,0,0,4701,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4702,0,0,0,0,0,0,0,0,0),
{ parameter }
         (0,4901,0,0,0,0,0,0,0,0,4901,4901,0,0,4901,0,0,0,0,4901,0,0,0,0,0,0,0,
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4902,0,0,0,0,0,0,0,0,0),
{ parameter type }
         (0,5101,0,0,0,0,0,0,0,0,5001,5001,0,0,5105,0,0,0,0,5001,0,0,0,0,0,0,0,
         0,0,0,5103,0,0,0,0,0,0,0,0,0,0,5102,0,0,0,0,0,0,0,0,0,5104,0,0,0,0,0),
{ comma list }
         (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5201,0,0,
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0),
{ statement }
         (0,0,0,0,0,0,0,0,0,5601,0,0,5701,5901,0,5901,0,6001,5501,0,5801,0,
          5901,0,5701,6101,5901,5901,5901,0,5901,5901,5901,0,5901,5901,5901,
          5901,5901,5901,5901,5901,5901,5901,5901,5901,5901,0,5901,5901,5401,
          5901,5601,5901,5901,5901,5901),
{ procedure call }
         (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6201,0,0,0,0,0,0),
{ argument list }
         (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6302,0,0,0,6303,
          0,0,0,0,0,0,0,0,0,0,6301,0,0,0,0,0,0,0,0,0,6304,0,6302,0,0,0),
{ arguments }
         (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6502,0,0,0,6501,
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6502,0,0,0),

{ argument }
         (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6801,0,0,0,0,0,0,
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6701,0,0,0),
{ sublist }
         (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6903,0,
          6902,0,0,0,0,0,0,0,0,6901,0,6902,6902,0,0,0,6902,6902,0,6904,0,6902,
          6902,0,6902),
{ return stmt }
         (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7301,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0),
{ ret expression }
         (7401,0,0,0,0,0,0,7401,0,0,0,0,0,7401,0,7401,0,0,0,0,0,0,7401,0,0,0,
          7401,7401,0,0,7401,7401,7401,0,7401,7401,7401,7401,7401,7401,7401,
          7401,7401,7401,7401,7401,7401,0,7401,7401,7401,7401,0,7401,7401,7401,
          7401),
{ if stmt }
         (0,0,0,0,0,0,0,0,0,7601,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0),
{ then clause }
         (0,0,0,0,0,0,0,0,0,7702,0,0,7702,0,0,0,0,7702,7702,0,7702,7701,0,0,
          7702,7702,7702,0,7702,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7702,
          0,7703,7702,0,0,0),
{ else clause }
         (0,0,0,7801,0,0,0,0,0,7802,0,0,7802,0,0,0,0,7802,7802,0,7802,0,0,0,
          7802,7802,7802,0,7802,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
          7802,0,7803,7802,0,0,0),
{ while stmt }
         (0,0,0,0,0,8007,0,0,0,8002,0,0,8001,0,0,0,0,8002,8002,0,8002,0,0,0,
          8003,8002,8002,0,8002,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
          8002,0,8005,8002,0,0,0),

{ stop stmt }
         (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8101,0,0,0,0,0,0,0,0,0,0,0,0,
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0),
{ assigment stmt }
         (8204,0,0,0,0,0,0,8204,0,0,0,0,0,8204,0,8204,0,0,0,0,0,0,8204,0,0,0,
          8301,8204,8203,0,8204,8204,8204,0,8204,8204,8204,8204,8204,8204,8204,
          8302,8204,8204,8204,8204,8204,0,8204,8204,8204,8305,0,8201,8204,8202,
          8204),
{ substring }
         (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8402,
          0,0,0,0,0,0,0,0,8401,0,8402,8402,0,0,0,8402,8402,0,8405,0,8402,8402,
          8403,8402),
{ start }
         (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8601,
          0,0,0,0,0,0,0,0,8601,0,8601,8601,0,0,0,8601,8601,0,8601,0,8601,8601,
          0,8601),
{ length }
         (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8701,
          0,0,0,0,0,0,0,0,8701,0,8701,8701,0,0,0,8701,8701,0,8701,0,8701,8701,
          0,8701),
{ read stmt }
         (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8901,0,0,0,0,0,0,0,0,8902,0,0,0,
          8902,0,0,0,0,0,0,0,0,0,0,8902,0,0,0,0,0,0,0,0,0,8902,0,8902,0,0,0),
{input goal list }
         (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9001,0,0,0,9002,
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9001,0,0,0),
{ input goals }
    (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9102,0,0,0,9101,0,0,0,
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9102,0,0,0),
{ input goal }
       (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9401,0,0,0,0,0,0,0,
          0,0,0,0,0,0,0,9402,0,0,0,0,0,0,0,0,0,9405,0,9301,0,0,0),
{ write stmt }
         (9502,0,0,0,0,0,0,9502,0,0,0,0,0,9502,0,9502,0,0,0,0,0,0,9502,9503,0,
          9501,9502,9502,0,0,9502,9502,9502,0,9520,9502,9502,9502,9502,9502,
          9502,9502,9502,9502,9502,9502,9502,0,9502,9502,9502,9502,0,9502,9502,
          9502,9502),
{ expression list }
         (9601,0,0,0,0,0,0,9601,0,0,0,0,0,9601,0,9601,0,0,0,0,0,0,9601,0,0,0,
          9601,9601,0,0,9602,9601,9601,0,9601,9601,9601,9601,9601,9601,9601,
          9601,9601,9601,9601,9601,9601,0,9601,9601,9601,9601,0,9601,9601,9601,
          9601),
{ expressions }
         (7102,0,0,0,0,0,0,7102,0,0,0,0,0,7102,0,7102,0,0,0,0,0,0,7102,0,0,0,
          7102,7102,0,0,7101,7102,7102,0,7102,7102,7102,7102,7102,7102,7102,
          7102,7102,7102,7102,7102,7102,0,7102,7102,7102,7102,0,7102,7102,7102,
          7102),
{ expression }
         (9801,0,0,0,0,0,0,9801,0,0,0,0,0,9801,0,9801,0,0,0,0,0,0,9801,0,0,0,
          9801,9801,0,0,0,9801,9801,0,9802,9802,9802,9801,9802,9801,9801,9801,
          9802,9801,9801,9801,9802,0,9801,9801,9801,9801,0,9801,9801,9801,
          9801),
{ etail }
         (9902,0,0,0,0,0,0,9902,0,0,0,0,0,9902,0,9902,0,0,0,0,0,0,9902,0,0,0,
          9902,9902,0,0,0,9902,9902,0,10101,10201,9901,9902,10301,9902,9902,
          9902,10001,9902,9902,9902,10401,0,9902,9902,9902,9902,0,9902,9902,
          9902,9902),
{ part }
         (10601,0,0,0,0,0,0,10601,0,0,0,0,0,10601,0,10602,0,0,0,0,0,0,10601,0,
          0,0,10601,10601,0,0,0,10601,10601,0,10601,10601,10601,10601,10601,
          10601,10601,10601,10601,10602,10601,10601,10601,0,10601,10602,10601,
          10601,0,10601,10601,10601,10601),
{ ptail }
         (10702,0,0,0,0,0,0,10702,0,0,0,0,0,10702,0,10901,0,0,0,0,0,0,10702,0,
          0,0,10702,10702,0,0,0,10702,10702,0,10702,10702,10702,10702,10702,
          10702,10702,10702,10702,10801,10702,10702,10702,0,10702,10701,10702,
          10702,0,10702,10702,10702,10702),
{ term }
         (11102,0,0,0,0,0,0,11101,0,0,0,0,0,11101,0,11101,0,0,0,0,0,0,11101,0,
          0,0,11101,11101,0,0,0,11101,11102,0,11101,11101,11101,11101,11101,
          11101,11101,11101,11101,11101,11102,11102,11101,0,11101,11101,11101,
          11101,0,11101,11101,11101,11101),
{ ttail }
         (11501,0,0,0,0,0,0,11201,0,0,0,0,0,11202,0,11202,0,0,0,0,0,0,11202,0,
          0,0,11202,11202,0,0,0,11202,11303,0,11202,11202,11202,11202,11202,
          11202,11202,11202,11202,11202,11201,11401,11202,0,11202,11202,11202,
          11202,0,11202,11202,11202,11202),
{ factor }
         (11901,0,0,0,0,0,0,11901,0,0,0,0,0,11701,0,11901,0,0,0,0,0,0,11901,0,
          0,0,11901,11901,0,0,0,11901,11901,0,11901,11901,11901,11901,11901,
          11901,11901,11901,11901,11901,11901,11901,11901,0,11901,11901,11901,
          11901,0,11901,11901,11901,11801),
{ index }
         (12101,0,0,0,0,0,0,12101,0,0,0,0,0,12101,0,12201,0,0,0,0,0,0,12201,0,
          0,0,12201,12201,0,0,0,12101,12101,0,12101,12101,12101,12101,12101,
          12001,12101,12101,12101,12101,12101,12101,12101,0,12101,12101,12101,
          12101,0,12101,12101,12101,12101),
{ itail }
         (12202,0,0,0,0,0,0,12202,0,0,0,0,0,12202,0,12202,0,0,0,0,0,0,12202,0,
          0,0,12202,12202,0,0,0,12202,12202,0,12202,12202,12202,12201,12202,
          12202,12202,12202,12202,12202,12202,12202,12202,0,12202,12202,12202,
          12202,0,12202,12202,12202,12202),
{ catena }
         (12402,0,0,0,0,0,0,12401,0,0,0,0,0,12402,0,12402,0,0,0,0,0,0,12401,0,
          0,0,12401,12401,0,0,0,12402,12402,0,12402,12402,12402,12402,12402,
          12402,12401,12401,12402,12402,12402,12402,12402,0,12401,12402,12401,
          12401,0,12401,12401,12401,12402),
{ ctail }
         (12502,0,0,0,0,0,0,12502,0,0,0,0,0,12502,0,12502,0,0,0,0,0,0,12502,0,
          0,0,12502,12502,0,0,0,12501,12502,0,12502,12502,12502,12502,12502,
          12502,12502,12502,12502,12502,12502,12502,12502,0,12502,12502,12502,
          12502,0,12502,12502,12502,12502),
{ primary }
         (12702,0,0,0,0,0,0,13601,0,0,0,0,0,12702,0,12702,0,0,0,0,0,0,13501,0,
          0,0,13101,13201,0,0,0,12702,12702,0,12702,12702,12702,12702,12702,
          12702,13401,12701,12702,12702,12702,12702,12702,0,13301,12702,12801,
          12703,0,12901,13001,12902,12702),
{ proc_name }
         (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
          0,0,0,0,0,0,0,0,0,0,0,0,0,13701,0,0,13801,0,0,0,0,0,0)  );

                                                                              {
         El siguiente procedimiento es utilizado para sacar y meter elementos
         al stack del parse
                                                                              }

         parse_string : array[159..161] of string[7] =('pop','accept','error');

       { VARIABLES DEL PROCEDIMIENTO llparse }
 Var
    parse : parse_stack;                      (*  stack del parse  *)
    parse_top : integer;                      (* tope del stack    *)
    true_top  : integer;              (* apuntador actual el tope del stack *)
    parse_action : integer;                   (* desde la tabla del parse *)
    i : integer;
    llparseflg:boolean;
{    fparseta  : file of parse_table;
    ll1_parsetab : parse_table;      { Antes una constante ahora una variable }
